.. Dipus Test Document documentation master file, created by
   sphinx-quickstart on Wed Aug 15 22:57:39 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Dipus Test Document's documentation!
===============================================

Contents:

.. toctree::
   :maxdepth: 2

   test-1
   dir/index
   README


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

